# Asimov Software Development Kit (SDK) for Python

[![License](https://img.shields.io/badge/license-Public%20Domain-blue.svg)](https://unlicense.org)
[![Compatibility](https://img.shields.io/badge/python-3.9%2B-blue)](https://pypi.org/project/asimov.py/)
[![Package](https://img.shields.io/pypi/v/asimov.py)](https://pypi.org/project/asimov.py/)

🚧 _We are building in public. This is presently under heavy construction._

## 🛠️ Prerequisites

- [Python](https://python.org) 3.9+
  (included in macOS 12.6+)

## ⬇️ Installation

### Installation via PyPI

```console
$ pip install asimov.py
```

## 👉 Examples

### Importing the SDK

```python
from asimov import sdk
```

### Initializing the SDK

```python
# TODO
```

### Examining SDK metadata

```python
# TODO
```

## 👨‍💻 Development

```console
$ git clone https://github.com/AsimovPlatform/asimov.py.git
```

- - -

[![Share on Twitter](https://img.shields.io/badge/share%20on-twitter-03A9F4?logo=twitter)](https://twitter.com/share?url=https://github.com/AsimovPlatform/asimov.py&text=Asimov%20Software%20Development%20Kit%20%28SDK%29%20for%20Python)
[![Share on Reddit](https://img.shields.io/badge/share%20on-reddit-red?logo=reddit)](https://reddit.com/submit?url=https://github.com/AsimovPlatform/asimov.py&title=Asimov%20Software%20Development%20Kit%20%28SDK%29%20for%20Python)
[![Share on Hacker News](https://img.shields.io/badge/share%20on-hacker%20news-orange?logo=ycombinator)](https://news.ycombinator.com/submitlink?u=https://github.com/AsimovPlatform/asimov.py&t=Asimov%20Software%20Development%20Kit%20%28SDK%29%20for%20Python)
[![Share on Facebook](https://img.shields.io/badge/share%20on-facebook-1976D2?logo=facebook)](https://www.facebook.com/sharer/sharer.php?u=https://github.com/AsimovPlatform/asimov.py)
[![Share on LinkedIn](https://img.shields.io/badge/share%20on-linkedin-3949AB?logo=linkedin)](https://www.linkedin.com/sharing/share-offsite/?url=https://github.com/AsimovPlatform/asimov.py)
